==> hal-app-0.3.0-sources.jar: org/jboss/hal/client/configuration/subsystem/datasource/wizard/Context.java <==
/*
 * Copyright 2015-2016 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.hal.client.configuration.subsystem.datasource.wizard;

import org.jboss.hal.client.configuration.subsystem.datasource.DataSource;
import org.jboss.hal.client.configuration.subsystem.datasource.DataSourceTemplate;
import org.jboss.hal.client.configuration.subsystem.datasource.JdbcDriver;

/**
 * @author Harald Pehl
 */
public class Context {

    final boolean standalone;
    final boolean xa;
    DataSourceTemplate template;
    DataSource dataSource;
    JdbcDriver driver;

    Context(boolean standalone, boolean xa) {
        this.standalone = standalone;
        this.xa = xa;
    }

    void custom() {
        dataSource = new DataSource(xa);
        driver = new JdbcDriver();
    }

    void useTemplate() {
        dataSource = template.getDataSource();
        driver = template.getDriver();
    }

    public DataSource getDataSource() {
        return dataSource;
    }
}

==> hal-app-0.4.0-sources.jar: org/jboss/hal/client/configuration/subsystem/datasource/wizard/Context.java <==
/*
 * Copyright 2015-2016 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.hal.client.configuration.subsystem.datasource.wizard;

import org.jboss.hal.core.datasource.DataSource;
import org.jboss.hal.client.configuration.subsystem.datasource.DataSourceTemplate;
import org.jboss.hal.core.datasource.JdbcDriver;

/**
 * @author Harald Pehl
 */
public class Context {

    private final boolean standalone;
    private final boolean xa;
    DataSourceTemplate template;
    DataSource dataSource;
    JdbcDriver driver;

    public Context(boolean standalone, boolean xa) {
        this.standalone = standalone;
        this.xa = xa;
    }

    void custom() {
        dataSource = new DataSource(xa);
        driver = new JdbcDriver();
    }

    void useTemplate() {
        dataSource = template.getDataSource();
        driver = template.getDriver();
    }

    public boolean isXa() {
        return xa;
    }

    public DataSource getDataSource() {
        return dataSource;
    }
}
